# junit.html

Report generated on 07-Aug-2023 at 07:23:51 by pytest-html v3.2.0

## Summary

16 tests ran in 1.13 seconds.

(Un)check the boxes to filter the results.

16 passed, 0 skipped, 0 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Passed | tests/test_scm.py::test_lookup | 0.03 |
No log output captured.
Passed | tests/test_scm.py::test_handle_remote_and_local_repos | 0.26 |
------------------------------Captured stderr call------------------------------ Switched to a new branch 'beta/0.0.3' Switched to a new branch 'beta/0.0.4' Switched to branch 'master' Cloning into '/tmp/pytest-of-runner/pytest-0/test_handle_remote_and_local_r0/test_check_version-repo1'... done. Switched to a new branch 'beta/0.0.2' Cloning into '/tmp/pytest-of-runner/pytest-0/test_handle_remote_and_local_r0/JQHCV9'... done. Switched to a new branch 'beta/0.0.1' fatal: a branch named 'master' already exists From /tmp/pytest-of-runner/pytest-0/test_handle_remote_and_local_r0/test_check_version-repo1 * [new branch] beta/0.0.2 -> repo1/beta/0.0.2 * [new branch] master -> repo1/master
Passed | tests/test_tools.py::test_abort_exception | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_urmtree | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_indent | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_list_of_paths | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_lstrip | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_apply_fixers | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_get_module_var | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_set_module_var | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_set_module_var_empty_file | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_bump_version | 0.00 |
No log output captured.
Passed | tests/test_tools.py::test_update_version_master | 0.05 |
No log output captured.
Passed | tests/test_tools.py::test_update_version_beta | 0.11 |
------------------------------Captured stderr call------------------------------ Switched to a new branch 'beta/0.0.4' Updated 1 path from the index Updated 1 path from the index Switched to a new branch 'beta/0.0.2'
Passed | tests/test_tools.py::test_update_version_release | 0.06 |
------------------------------Captured stderr call------------------------------ Switched to a new branch 'beta/0.0.3' Updated 1 path from the index
Passed | tests/test_tools.py::test_process | 0.13 |
------------------------------Captured stderr call------------------------------ Updated 1 path from the index Switched to a new branch 'beta/1.2.3'